@@ -36,7 +36,7 @@ use constant CLIGHT => 2.99792458e5;
 
 use vars qw/ $VERSION /;
 
-$VERSION = "1.50";
+$VERSION = "1.55";
 
 # Cache UTC definition
 our $UTC = DateTime::TimeZone->new( name => 'UTC' );
@@ -102,12 +102,13 @@ sub can_translate {
        $headers->{BACKEND} =~ /^ACSIS/i
      ) {
     return 1;
+
+  # BACKEND will discriminate between DAS files converted to ACSIS format
+  # from GSD format directly (handled by Astro::FITS::HdrTrans::JCMT_GSD).
   } elsif ( exists $headers->{BACKEND} &&
             defined $headers->{BACKEND} &&
             $headers->{BACKEND} =~ /^DAS/i &&
-            exists $headers->{OBSID} &&
-            defined $headers->{OBSID} &&
-            $headers->{OBSID} =~ /^DAS/) {
+            ! (exists $headers->{'GSDFILE'} && exists $headers->{'SCA#'})) {
     # Do not want to confuse with reverse conversion
     # of JCMT_GSD data headers which will have a defined
     # BACKEND header of DAS.
